@@ -101,7 +101,7 @@ class Eaves:
             if func_before_running:
                 ret = func.__annotations__['return']
                 def new_func(events) -> ret:
-                    func(func_before_running(events))
+                    return func(func_before_running(events))
 
                 self.handlers[name] = new_func
             else:
